Reader

Struct Reader 

pub struct Reader<R>(/* private fields */)
where
    R: AsyncRead + Unpin;
An async alignment reader.

Implementations

Source

impl<R> Reader<R>
where R: AsyncRead + Unpin,

pub async fn new(reader: R) -> Result<Self>

Creates an async alignment reader.

This attempts to autodetect the compression method and format of the input.

Examples
use noodles_util::alignment;
use tokio::io;
let reader = alignment::r#async::io::Reader::new(io::empty()).await?;
pub async fn read_header(&mut self) -> Result<Header>

Reads the SAM header.

Examples
use noodles_util::alignment;
use tokio::io;
let mut reader = alignment::r#async::io::Reader::new(io::empty()).await?;
let header = reader.read_header().await?;
pub fn records<'r, 'h: 'r>( &'r mut self, header: &'h Header, ) -> impl Stream<Item = Result<Box<dyn Record>>> + 'r

Returns an iterator over records starting from the current stream position.

Examples
use futures::TryStreamExt;
use noodles_util::alignment;
use tokio::io;

let mut reader = alignment::r#async::io::Reader::new(io::empty()).await?;
let header = reader.read_header().await?;

let mut records = reader.records(&header);

while let Some(record) = records.try_next().await? {
    // ...
}